BuiltInPrinterType enum

Inheritance
Available extensions

Values

none → const BuiltInPrinterType

Không tìm thấy máy in tích hợp

const BuiltInPrinterType(0)
mm58 → const BuiltInPrinterType

Máy in nhiệt khổ 58mm (K57)

const BuiltInPrinterType(58)
mm80 → const BuiltInPrinterType

Máy in nhiệt khổ 80mm (K80)

const BuiltInPrinterType(80)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
paperSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPaperSize(int size) BuiltInPrinterType

Constants

values → const List<BuiltInPrinterType>
A constant List of the values in this enum, in order of their declaration.