ESCPrintServicePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ESCPrintServicePlatform

Constructors

ESCPrintServicePlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDrawer({String? deviceId, PrinterConnectionType? connectionType}) Future<bool>
Opens the connected cash drawer via ESC/POS command (ESC p) or native cash drawer port.
openDrawerMultiDevices({required List<String> deviceIds}) Future<void>
Opens the cash drawer on multiple specified printer devices concurrently.
print({String? deviceId, PrinterConnectionType? connectionType, required PrintThermalModel model, bool openDrawer}) Future<void>
In hóa đơn. openDrawer = true thì mở két TRƯỚC khi gửi bill (thanh toán tiền mặt). Xem PrinterLabel.printESC để biết lý do mở trước thay vì sau.
printBarcode({String? deviceId, PrinterConnectionType? connectionType, required String code, String type = "128", int width = 2, int height = 162}) Future<void>
printQRCode({String? deviceId, PrinterConnectionType? connectionType, required String code, int size = 8}) Future<void>
printText({String? deviceId, PrinterConnectionType? connectionType, required String text}) Future<void>
printWidget({required Widget widget, required TicketSize size, String? deviceId, PrinterConnectionType? connectionType, double? pixelRatio, bool openDrawer}) Future<void>
Captures the given widget as an image and prints it using ESC/POS protocol.
printWidgetToDevices({required Widget widget, required TicketSize size, required List<String?> deviceIds, double? pixelRatio, bool openDrawer}) Future<void>
Chụp widget một lần rồi in song song ra tất cả deviceIds.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ESCPrintServicePlatform
getter/setter pair