MethodChannelPrinterLabel class

Inheritance

Constructors

MethodChannelPrinterLabel()

Properties

bluetoothScanStream Stream<BluetoothDeviceModel>
Stream các device được discover trong quá trình scan. Gọi startBluetoothScan trước khi listen trên iOS.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
platformVersion Future<String?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usbDeviceStream Stream<UsbConnectionEvent>
no setteroverride

Methods

checkConnect({String? deviceId}) Future<bool>
override
connectBluetooth({required String macAddress}) Future<bool>
identifier trên iOS là UUID string của CBPeripheral. Trên Android là MAC address. Giữ tên param là macAddress để tương thích backward.
override
connectLan({required String ipAddress}) Future<bool>
override
disconectPrinter({String? deviceId}) Future<bool>
override
getAllConnections() Future<Map<String, bool>>
override
getBluetoothDevices() Future<List<BluetoothDeviceModel>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printAll({LabelModel? labelModel, PrintThermalModel? escModel, PrinterConnectionType? connectionType}) Future<void>
override
printBarcode({String? deviceId, PrinterConnectionType? connectionType, required BarcodeModel printBarcodeModel}) Future<void>
override
printESC({String? deviceId, PrinterConnectionType? connectionType, required PrintThermalModel printThermalModel}) Future<void>
override
printImage({String? deviceId, PrinterConnectionType? connectionType, required ImageModel imageModel}) Future<void>
override
printLabel({String? deviceId, PrinterConnectionType? connectionType, required LabelModel labelModel}) Future<void>
override
startBluetoothScan() Future<bool>
iOS: bắt đầu scan BLE — devices stream qua bluetoothScanStream Android: no-op (Android tự scan)
override
stopBluetoothScan() Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited