PrinterMethod enum
Values
- getPlatformVersion → const PrinterMethod
-
const PrinterMethod('getPlatformVersion') - checkConnect → const PrinterMethod
-
const PrinterMethod('checkConnect') - disconnect → const PrinterMethod
-
const PrinterMethod('disconnect') - connectLan → const PrinterMethod
-
const PrinterMethod('connect_lan') - connectBt → const PrinterMethod
-
const PrinterMethod('connect_bt') - scanBt → const PrinterMethod
-
const PrinterMethod('scan_bt') - stopScanBt → const PrinterMethod
-
const PrinterMethod('stop_scan_bt') - getBluetoothDevices → const PrinterMethod
-
const PrinterMethod('get_bluetooth_devices') - printBarcode → const PrinterMethod
-
const PrinterMethod('print_barcode') - printLabel → const PrinterMethod
-
const PrinterMethod('print_label') - printImage → const PrinterMethod
-
const PrinterMethod('print_image') - printImageEsc → const PrinterMethod
-
const PrinterMethod('print_image_esc') - printAll → const PrinterMethod
-
const PrinterMethod('print_all')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrinterMethod> - A constant List of the values in this enum, in order of their declaration.