BluetoothDeviceModel class
Constructors
- BluetoothDeviceModel({required String name, required String identifier})
-
const
-
BluetoothDeviceModel.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Platform-specific device identifier:
final
- mac → String
-
Backward-compat alias for identifier
no setter
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited